@@ -29,6 +29,7 @@
     #include <openrct2-ui/interface/Window.h>
     #include <openrct2/config/Config.h>
     #include <openrct2/core/Console.hpp>
+    #include <openrct2/drawing/Drawing.String.h>
     #include <openrct2/drawing/Drawing.h>
     #include <openrct2/drawing/IDrawingContext.h>
     #include <openrct2/drawing/IDrawingEngine.h>
@@ -613,7 +614,7 @@ private:
         }
         if (GetContext()->GetUiContext().GetScaleQuality() == ScaleQuality::SmoothNearestNeighbour)
         {
-            uint32_t scale = std::ceil(Config::Get().general.WindowScale);
+            uint32_t scale = std::ceil(Config::Get().general.windowScale);
             _smoothScaleFramebuffer = std::make_unique<OpenGLFramebuffer>(_width * scale, _height * scale, false, false);
         }
     }
@@ -877,7 +878,7 @@ void OpenGLDrawingContext::DrawSprite(RenderTarget& rt, const ImageId imageId, c
 
     if (rt.zoom_level > ZoomLevel{ 0 })
     {
-        if (g1Element->flags & G1_FLAG_HAS_ZOOM_SPRITE)
+        if (g1Element->flags.has(G1Flag::hasZoomSprite))
         {
             RenderTarget zoomedRT;
             zoomedRT.bits = rt.bits;
@@ -887,10 +888,10 @@ void OpenGLDrawingContext::DrawSprite(RenderTarget& rt, const ImageId imageId, c
             zoomedRT.width = rt.width;
             zoomedRT.pitch = rt.pitch;
             zoomedRT.zoom_level = rt.zoom_level - 1;
-            DrawSprite(zoomedRT, imageId.WithIndex(imageId.GetIndex() - g1Element->zoomed_offset), x >> 1, y >> 1);
+            DrawSprite(zoomedRT, imageId.WithIndex(imageId.GetIndex() - g1Element->zoomedOffset), x >> 1, y >> 1);
             return;
         }
-        if (g1Element->flags & G1_FLAG_NO_ZOOM_DRAW)
+        if (g1Element->flags.has(G1Flag::noZoomDraw))
         {
             return;
         }
@@ -898,8 +899,8 @@ void OpenGLDrawingContext::DrawSprite(RenderTarget& rt, const ImageId imageId, c
 
     auto texture = _textureCache->GetOrLoadImageTexture(imageId);
 
-    int32_t left = x + g1Element->x_offset;
-    int32_t top = y + g1Element->y_offset;
+    int32_t left = x + g1Element->xOffset;
+    int32_t top = y + g1Element->yOffset;
 
     int32_t xModifier = 0;
     int32_t yModifier = 0;
@@ -1014,8 +1015,8 @@ void OpenGLDrawingContext::DrawSpriteRawMasked(
     const auto textureMask = _textureCache->GetOrLoadImageTexture(maskImage);
     const auto textureColour = _textureCache->GetOrLoadImageTexture(colourImage);
 
-    int32_t drawOffsetX = g1ElementMask->x_offset;
-    int32_t drawOffsetY = g1ElementMask->y_offset;
+    int32_t drawOffsetX = g1ElementMask->xOffset;
+    int32_t drawOffsetY = g1ElementMask->yOffset;
     int32_t drawWidth = std::min(g1ElementMask->width, g1ElementColour->width);
     int32_t drawHeight = std::min(g1ElementMask->height, g1ElementColour->height);
 
@@ -1074,8 +1075,8 @@ void OpenGLDrawingContext::DrawSpriteSolid(RenderTarget& rt, const ImageId image
 
     const auto texture = _textureCache->GetOrLoadImageTexture(image);
 
-    int32_t drawOffsetX = g1Element->x_offset;
-    int32_t drawOffsetY = g1Element->y_offset;
+    int32_t drawOffsetX = g1Element->xOffset;
+    int32_t drawOffsetY = g1Element->yOffset;
     int32_t drawWidth = static_cast<uint16_t>(g1Element->width);
     int32_t drawHeight = static_cast<uint16_t>(g1Element->height);
 
@@ -1126,8 +1127,8 @@ void OpenGLDrawingContext::DrawGlyph(RenderTarget& rt, const ImageId image, int3
 
     const auto texture = _textureCache->GetOrLoadGlyphTexture(image, palette);
 
-    int32_t left = x + g1Element->x_offset;
-    int32_t top = y + g1Element->y_offset;
+    int32_t left = x + g1Element->xOffset;
+    int32_t top = y + g1Element->yOffset;
     int32_t right = left + static_cast<uint16_t>(g1Element->width);
     int32_t bottom = top + static_cast<uint16_t>(g1Element->height);
 
@@ -1210,7 +1211,7 @@ void OpenGLDrawingContext::DrawTTFBitmap(
     right += clip.GetLeft() - rt.x;
     bottom += clip.GetTop() - rt.y;
 
-    if (info->flags & TEXT_DRAW_FLAG_OUTLINE)
+    if (info->colourFlags.has(ColourFlag::withOutline))
     {
         std::array<ivec4, 4> boundsArr = { {
             { left + 1, top, right + 1, bottom },
@@ -1228,13 +1229,13 @@ void OpenGLDrawingContext::DrawTTFBitmap(
             command.texMaskBounds = { 0.0f, 0.0f, 0.0f, 0.0f };
             command.palettes = { 0, 0, 0 };
             command.flags = DrawRectCommand::FLAG_TTF_TEXT;
-            command.colour = info->palette[3];
+            command.colour = info->palette.shadowOutline;
             command.bounds = b;
             command.depth = _drawCount++;
             command.zoom = 1.0f;
         }
     }
-    if (info->flags & TEXT_DRAW_FLAG_INSET)
+    if (info->colourFlags.has(ColourFlag::inset))
     {
         DrawRectCommand& command = _commandBuffers.rects.allocate();
         command.clip = { clip.GetLeft(), clip.GetTop(), clip.GetRight(), clip.GetBottom() };
@@ -1244,7 +1245,7 @@ void OpenGLDrawingContext::DrawTTFBitmap(
         command.texMaskBounds = { 0.0f, 0.0f, 0.0f, 0.0f };
         command.palettes = { 0, 0, 0 };
         command.flags = DrawRectCommand::FLAG_TTF_TEXT;
-        command.colour = info->palette[3];
+        command.colour = info->palette.shadowOutline;
         command.bounds = { left + 1, top + 1, right + 1, bottom + 1 };
         command.depth = _drawCount++;
         command.zoom = 1.0f;
@@ -1258,7 +1259,7 @@ void OpenGLDrawingContext::DrawTTFBitmap(
     command.texMaskBounds = { 0.0f, 0.0f, 0.0f, 0.0f };
     command.palettes = { 0, 0, 0 };
     command.flags = DrawRectCommand::FLAG_TTF_TEXT | (hintingThreshold << 8);
-    command.colour = info->palette[1];
+    command.colour = info->palette.fill;
     command.bounds = { left, top, right, bottom };
     command.depth = _drawCount++;
     command.zoom = 1.0f;
