@@ -228,7 +228,7 @@ namespace OpenRCT2::Ui::Windows
             CommonPrepareDrawAfter();
         }
 
-        void onDraw(RenderTarget& rt) override
+        void onDraw(Drawing::RenderTarget& rt) override
         {
             drawWidgets(rt);
             DrawTabImages(rt);
@@ -388,7 +388,7 @@ namespace OpenRCT2::Ui::Windows
                                                                 Network::GetCurrentPlayerId() };
                     pickupAction.SetCallback(
                         [peepnum = number](const GameActions::GameAction* ga, const GameActions::Result* result) {
-                            if (result->Error != GameActions::Status::Ok)
+                            if (result->error != GameActions::Status::ok)
                                 return;
 
                             auto* windowMgr = GetWindowManager();
@@ -435,7 +435,7 @@ namespace OpenRCT2::Ui::Windows
                     gDropdown.items[1] = Dropdown::PlainMenuLabel(STR_CLEAR_PATROL_AREA);
 
                     auto ddPos = ScreenCoordsXY{ widget->left + windowPos.x, widget->top + windowPos.y };
-                    int32_t extraHeight = widget->height() + 1;
+                    int32_t extraHeight = widget->height();
                     WindowDropdownShowText(ddPos, extraHeight, colours[1], 0, 2);
                     gDropdown.defaultIndex = 0;
 
@@ -540,7 +540,7 @@ namespace OpenRCT2::Ui::Windows
             widgets[WIDX_FIRE].right = width - 2;
         }
 
-        void OverviewDraw(RenderTarget& rt)
+        void OverviewDraw(Drawing::RenderTarget& rt)
         {
             // Draw the viewport no sound sprite
             if (viewport != nullptr)
@@ -563,23 +563,23 @@ namespace OpenRCT2::Ui::Windows
             staff->FormatActionTo(ft);
             const auto& widget = widgets[WIDX_BTM_LABEL];
             auto screenPos = windowPos + ScreenCoordsXY{ widget.midX(), widget.top };
-            int32_t widgetWidth = widget.width();
-            DrawTextEllipsised(rt, screenPos, widgetWidth, STR_BLACK_STRING, ft, { TextAlignment::CENTRE });
+            int32_t widgetWidth = widget.width() - 1;
+            DrawTextEllipsised(rt, screenPos, widgetWidth, STR_BLACK_STRING, ft, { TextAlignment::centre });
         }
 
-        void DrawOverviewTabImage(RenderTarget& rt)
+        void DrawOverviewTabImage(Drawing::RenderTarget& rt)
         {
             if (isWidgetDisabled(WIDX_TAB_1))
                 return;
 
             const auto& widget = widgets[WIDX_TAB_1];
-            int32_t widgetWidth = widget.width() - 1;
-            int32_t widgetHeight = widget.height() - 1;
+            int32_t widgetWidth = widget.width() - 2;
+            int32_t widgetHeight = widget.height() - 2;
             auto screenCoords = windowPos + ScreenCoordsXY{ widget.left + 1, widget.top + 1 };
             if (page == WINDOW_STAFF_OVERVIEW)
                 widgetHeight++;
 
-            RenderTarget clippedRT;
+            Drawing::RenderTarget clippedRT;
             if (!ClipDrawPixelInfo(clippedRT, rt, screenCoords, widgetWidth, widgetHeight))
             {
                 return;
@@ -615,8 +615,8 @@ namespace OpenRCT2::Ui::Windows
             if (viewport != nullptr)
             {
                 const Widget& viewportWidget = widgets[WIDX_VIEWPORT];
-                const auto reqViewportWidth = viewportWidget.width() - 1;
-                const auto reqViewportHeight = viewportWidget.height() - 1;
+                const auto reqViewportWidth = viewportWidget.width() - 2;
+                const auto reqViewportHeight = viewportWidget.height() - 2;
 
                 viewport->pos = windowPos + ScreenCoordsXY{ viewportWidget.left + 1, viewportWidget.top + 1 };
                 if (viewport->width != reqViewportWidth || viewport->height != reqViewportHeight)
@@ -668,8 +668,6 @@ namespace OpenRCT2::Ui::Windows
             if (widgetIndex != WIDX_PICKUP)
                 return;
 
-            MapInvalidateSelectionRect();
-
             gMapSelectFlags.unset(MapSelectFlag::enable);
 
             auto mapCoords = FootpathGetCoordinatesFromPos({ screenCoords.x, screenCoords.y + 16 }, nullptr, nullptr);
@@ -679,7 +677,6 @@ namespace OpenRCT2::Ui::Windows
                 gMapSelectType = MapSelectType::full;
                 gMapSelectPositionA = mapCoords;
                 gMapSelectPositionB = mapCoords;
-                MapInvalidateSelectionRect();
             }
 
             gPickupPeepImage = ImageId();
@@ -722,7 +719,7 @@ namespace OpenRCT2::Ui::Windows
                                                         { destCoords, tileElement->GetBaseZ() },
                                                         Network::GetCurrentPlayerId() };
             pickupAction.SetCallback([](const GameActions::GameAction* ga, const GameActions::Result* result) {
-                if (result->Error != GameActions::Status::Ok)
+                if (result->error != GameActions::Status::ok)
                     return;
                 ToolCancel();
                 gPickupPeepImage = ImageId();
@@ -802,8 +799,8 @@ namespace OpenRCT2::Ui::Windows
             }
 
             auto ddPos = ScreenCoordsXY{ ddWidget->left + windowPos.x, ddWidget->top + windowPos.y };
-            int32_t ddHeight = ddWidget->height() + 1;
-            int32_t ddWidth = ddWidget->width() - 3;
+            int32_t ddHeight = ddWidget->height();
+            int32_t ddWidth = ddWidget->width() - 4;
             WindowDropdownShowTextCustomWidth(ddPos, ddHeight, colours[1], 0, Dropdown::Flag::StayOpen, numCostumes, ddWidth);
 
             // Set selection
@@ -931,7 +928,7 @@ namespace OpenRCT2::Ui::Windows
 #pragma endregion
 
 #pragma region Statistics tab events
-        void StatsDraw(RenderTarget& rt)
+        void StatsDraw(Drawing::RenderTarget& rt)
         {
             auto staff = GetStaff();
             if (staff == nullptr)
@@ -1158,8 +1155,8 @@ namespace OpenRCT2::Ui::Windows
                     const auto& viewWidget = widgets[WIDX_VIEWPORT];
 
                     auto screenPos = ScreenCoordsXY{ viewWidget.left + 1 + windowPos.x, viewWidget.top + 1 + windowPos.y };
-                    int32_t viewportWidth = viewWidget.width() - 1;
-                    int32_t viewportHeight = viewWidget.height() - 1;
+                    int32_t viewportWidth = viewWidget.width() - 2;
+                    int32_t viewportHeight = viewWidget.height() - 2;
 
                     ViewportCreate(*this, screenPos, viewportWidth, viewportHeight, focus.value());
                     flags |= WindowFlag::noScrolling;
@@ -1178,7 +1175,7 @@ namespace OpenRCT2::Ui::Windows
             gDropdown.items[1] = Dropdown::PlainMenuLabel(STR_FOLLOW_SUBJECT_TIP);
 
             WindowDropdownShowText(
-                { windowPos.x + widget->left, windowPos.y + widget->top }, widget->height() + 1, colours[1], 0, 2);
+                { windowPos.x + widget->left, windowPos.y + widget->top }, widget->height(), colours[1], 0, 2);
             gDropdown.defaultIndex = 0;
         }
 
@@ -1188,14 +1185,14 @@ namespace OpenRCT2::Ui::Windows
             WindowFollowSprite(*main, EntityId::FromUnderlying(number));
         }
 
-        void DrawTabImages(RenderTarget& rt)
+        void DrawTabImages(Drawing::RenderTarget& rt)
         {
             DrawOverviewTabImage(rt);
             DrawTabImage(rt, WINDOW_STAFF_OPTIONS, SPR_TAB_STAFF_OPTIONS_0);
             DrawTabImage(rt, WINDOW_STAFF_STATISTICS, SPR_TAB_STATS_0);
         }
 
-        void DrawTabImage(RenderTarget& rt, int32_t p, int32_t baseImageId)
+        void DrawTabImage(Drawing::RenderTarget& rt, int32_t p, int32_t baseImageId)
         {
             WidgetIndex widgetIndex = WIDX_TAB_1 + p;
             Widget* widget = &widgets[widgetIndex];
