@@ -30,8 +30,8 @@
 #include "core/FileScanner.h"
 #include "core/Money.hpp"
 #include "core/Path.hpp"
-#include "core/SawyerCoding.h"
 #include "core/String.hpp"
+#include "entity/EntityList.h"
 #include "entity/EntityRegistry.h"
 #include "entity/PatrolArea.h"
 #include "entity/Peep.h"
@@ -56,6 +56,7 @@
 #include "ride/Track.h"
 #include "ride/TrackDesign.h"
 #include "ride/Vehicle.h"
+#include "sawyer_coding/SawyerCoding.h"
 #include "scenario/Scenario.h"
 #include "scenes/title/TitleScene.h"
 #include "scripting/ScriptEngine.h"
@@ -76,11 +77,18 @@
 #include <iterator>
 #include <memory>
 
+#ifdef __EMSCRIPTEN__
+extern "C" {
+extern void EmscriptenSaveGame(bool isTrackDesign, bool isAutosave, LoadSaveType type);
+extern void EmscriptenResetAutosave();
+}
+#endif
+
 using namespace OpenRCT2;
 
 uint16_t gCurrentDeltaTime;
 uint8_t gGamePaused = 0;
-int32_t gGameSpeed = 1;
+uint8_t gGameSpeed = 1;
 bool gDoSingleUpdate = false;
 float gDayNightCycle = 0;
 bool gInUpdateCode = false;
@@ -101,18 +109,18 @@ using namespace OpenRCT2;
 
 void GameResetSpeed()
 {
-    auto setSpeedAction = GameSetSpeedAction(1);
-    GameActions::Execute(&setSpeedAction);
+    auto setSpeedAction = GameActions::GameSetSpeedAction(1);
+    GameActions::Execute(&setSpeedAction, getGameState());
 }
 
 void GameIncreaseGameSpeed()
 {
-    auto newSpeed = std::min(Config::Get().general.DebuggingTools ? 5 : 4, gGameSpeed + 1);
+    auto newSpeed = std::min(Config::Get().general.debuggingTools ? 5 : 4, gGameSpeed + 1);
     if (newSpeed == 5)
         newSpeed = 8;
 
-    auto setSpeedAction = GameSetSpeedAction(newSpeed);
-    GameActions::Execute(&setSpeedAction);
+    auto setSpeedAction = GameActions::GameSetSpeedAction(newSpeed);
+    GameActions::Execute(&setSpeedAction, getGameState());
 }
 
 void GameReduceGameSpeed()
@@ -121,8 +129,8 @@ void GameReduceGameSpeed()
     if (newSpeed == 7)
         newSpeed = 4;
 
-    auto setSpeedAction = GameSetSpeedAction(newSpeed);
-    GameActions::Execute(&setSpeedAction);
+    auto setSpeedAction = GameActions::GameSetSpeedAction(newSpeed);
+    GameActions::Execute(&setSpeedAction, getGameState());
 }
 
 /**
@@ -131,9 +139,9 @@ void GameReduceGameSpeed()
  */
 void GameCreateWindows()
 {
-    ContextOpenWindow(WindowClass::MainWindow);
-    ContextOpenWindow(WindowClass::TopToolbar);
-    ContextOpenWindow(WindowClass::BottomToolbar);
+    ContextOpenWindow(WindowClass::mainWindow);
+    ContextOpenWindow(WindowClass::topToolbar);
+    ContextOpenWindow(WindowClass::bottomToolbar);
     WindowResizeGui(ContextGetWidth(), ContextGetHeight());
 }
 
@@ -142,7 +150,7 @@ void PauseToggle()
     gGamePaused ^= GAME_PAUSED_NORMAL;
 
     auto* windowMgr = Ui::GetWindowManager();
-    windowMgr->InvalidateByClass(WindowClass::TopToolbar);
+    windowMgr->InvalidateByClass(WindowClass::topToolbar);
 
     if (gGamePaused & GAME_PAUSED_NORMAL)
     {
@@ -166,8 +174,9 @@ bool GameIsNotPaused()
  */
 static void LoadLandscape()
 {
-    auto intent = Intent(WindowClass::Loadsave);
-    intent.PutExtra(INTENT_EXTRA_LOADSAVE_TYPE, LOADSAVETYPE_LOAD | LOADSAVETYPE_LANDSCAPE);
+    auto intent = Intent(WindowClass::loadsave);
+    intent.PutEnumExtra<LoadSaveAction>(INTENT_EXTRA_LOADSAVE_ACTION, LoadSaveAction::load);
+    intent.PutEnumExtra<LoadSaveType>(INTENT_EXTRA_LOADSAVE_TYPE, LoadSaveType::landscape);
     ContextOpenIntent(&intent);
 }
 
@@ -175,32 +184,31 @@ void RCT2StringToUTF8Self(char* buffer, size_t length)
 {
     if (length > 0)
     {
-        auto temp = RCT2StringToUTF8(buffer, RCT2LanguageId::EnglishUK);
+        auto temp = RCT2StringToUTF8(buffer, RCT2LanguageId::englishUK);
         String::safeUtf8Copy(buffer, temp.data(), length);
     }
 }
 
 static void FixGuestsHeadingToParkCount()
 {
-    auto& gameState = GetGameState();
-
     uint32_t guestsHeadingToPark = 0;
 
     for (auto* peep : EntityList<Guest>())
     {
-        if (peep->OutsideOfPark && peep->State != PeepState::LeavingPark)
+        if (peep->OutsideOfPark && peep->State != PeepState::leavingPark)
         {
             guestsHeadingToPark++;
         }
     }
 
-    if (gameState.NumGuestsHeadingForPark != guestsHeadingToPark)
+    auto& park = getGameState().park;
+    if (park.numGuestsHeadingForPark != guestsHeadingToPark)
     {
-        LOG_WARNING(
-            "Corrected bad amount of guests heading to park: %u -> %u", gameState.NumGuestsHeadingForPark, guestsHeadingToPark);
+        LOG_VERBOSE(
+            "Corrected bad amount of guests heading to park: %u -> %u", park.numGuestsHeadingForPark, guestsHeadingToPark);
     }
 
-    gameState.NumGuestsHeadingForPark = guestsHeadingToPark;
+    park.numGuestsHeadingForPark = guestsHeadingToPark;
 }
 
 static void FixGuestCount()
@@ -216,13 +224,13 @@ static void FixGuestCount()
         }
     }
 
-    auto& gameState = GetGameState();
-    if (gameState.NumGuestsInPark != guestCount)
+    auto& park = getGameState().park;
+    if (park.numGuestsInPark != guestCount)
     {
-        LOG_WARNING("Corrected bad amount of guests in park: %u -> %u", gameState.NumGuestsInPark, guestCount);
+        LOG_VERBOSE("Corrected bad amount of guests in park: %u -> %u", park.numGuestsInPark, guestCount);
     }
 
-    gameState.NumGuestsInPark = guestCount;
+    park.numGuestsInPark = guestCount;
 }
 
 static void FixPeepsWithInvalidRideReference()
@@ -269,7 +277,7 @@ static void FixPeepsWithInvalidRideReference()
     if (!peepsToRemove.empty())
     {
         // Some broken saves have broken spatial indexes
-        ResetEntitySpatialIndices();
+        getGameState().entities.ResetEntitySpatialIndices();
     }
 
     for (auto ptr : peepsToRemove)
@@ -302,8 +310,8 @@ static void FixInvalidSurfaces()
 
             // Fix the invisible border tiles.
             // At this point, we can be sure that surfaceElement is not NULL.
-            auto& gameState = GetGameState();
-            if (x == 0 || x == gameState.MapSize.x - 1 || y == 0 || y == gameState.MapSize.y - 1)
+            auto& gameState = getGameState();
+            if (x == 0 || x == gameState.mapSize.x - 1 || y == 0 || y == gameState.mapSize.y - 1)
             {
                 surfaceElement->SetBaseZ(kMinimumLandZ);
                 surfaceElement->SetClearanceZ(kMinimumLandZ);
@@ -356,7 +364,7 @@ void GameLoadInit()
 
     if (!gLoadKeepWindowsOpen)
     {
-        ViewportInitAll();
+        ContextResetSubsystems();
         GameCreateWindows();
     }
     else
@@ -365,15 +373,15 @@ void GameLoadInit()
         WindowUnfollowSprite(*mainWindow);
     }
 
-    auto windowManager = context->GetUiContext()->GetWindowManager();
-    auto& gameState = GetGameState();
-    windowManager->SetMainView(gameState.SavedView, gameState.SavedViewZoom, gameState.SavedViewRotation);
+    auto windowManager = context->GetUiContext().GetWindowManager();
+    auto& gameState = getGameState();
+    windowManager->SetMainView(gameState.savedView, gameState.savedViewZoom, gameState.savedViewRotation);
 
-    if (NetworkGetMode() != NETWORK_MODE_CLIENT)
+    if (Network::GetMode() != Network::Mode::client)
     {
         GameActions::ClearQueue();
     }
-    ResetEntitySpatialIndices();
+    getGameState().entities.ResetEntitySpatialIndices();
     ResetAllSpriteQuadrantPlacements();
 
     gWindowUpdateTicks = 0;
@@ -416,7 +424,7 @@ void GameNotifyMapChange()
 
     auto& scriptEngine = GetContext()->GetScriptEngine();
     auto& hookEngine = scriptEngine.GetHookEngine();
-    hookEngine.Call(HOOK_TYPE::MAP_CHANGE, false);
+    hookEngine.Call(HookType::mapChange, false);
     _mapChangedExpected = true;
 #endif
 }
@@ -428,7 +436,7 @@ void GameNotifyMapChanged()
 
     auto& scriptEngine = GetContext()->GetScriptEngine();
     auto& hookEngine = scriptEngine.GetHookEngine();
-    hookEngine.Call(HOOK_TYPE::MAP_CHANGED, false);
+    hookEngine.Call(HookType::mapChanged, false);
     _mapChangedExpected = false;
 #endif
 }
@@ -442,8 +450,8 @@ void ResetAllSpriteQuadrantPlacements()
 {
     for (EntityId::UnderlyingType i = 0; i < kMaxEntities; i++)
     {
-        auto* spr = GetEntity(EntityId::FromUnderlying(i));
-        if (spr != nullptr && spr->Type != EntityType::Null)
+        auto* spr = getGameState().entities.GetEntity(EntityId::FromUnderlying(i));
+        if (spr != nullptr && spr->Type != EntityType::null)
         {
             spr->MoveTo(spr->GetLocation());
         }
@@ -454,8 +462,14 @@ void SaveGame()
 {
     if (!gFirstTimeSaving && !gIsAutosaveLoaded)
     {
+#ifndef __EMSCRIPTEN__
         const auto savePath = Path::WithExtension(gScenarioSavePath, ".park");
         SaveGameWithName(savePath);
+#else
+        const auto savePath = Path::WithExtension("save", ".park");
+        SaveGameWithName(savePath);
+        EmscriptenSaveGame(false, false, LoadSaveType::park);
+#endif
     }
     else
     {
@@ -473,8 +487,8 @@ void SaveGameCmd(u8string_view name /* = {} */)
     }
     else
     {
-        auto env = GetContext()->GetPlatformEnvironment();
-        auto savePath = Path::Combine(env->GetDirectoryPath(DIRBASE::USER, DIRID::SAVE), u8string(name) + u8".park");
+        auto& env = GetContext()->GetPlatformEnvironment();
+        auto savePath = Path::Combine(env.GetDirectoryPath(DirBase::user, DirId::saves), u8string(name) + u8".park");
         SaveGameWithName(savePath);
     }
 }
@@ -483,8 +497,8 @@ void SaveGameWithName(u8string_view name)
 {
     LOG_VERBOSE("Saving to %s", u8string(name).c_str());
 
-    auto& gameState = GetGameState();
-    if (ScenarioSave(gameState, name, Config::Get().general.SavePluginData ? 1 : 0))
+    auto& gameState = getGameState();
+    if (ScenarioSave(gameState, name, Config::Get().general.savePluginData ? 1 : 0))
     {
         LOG_VERBOSE("Saved to %s", u8string(name).c_str());
         gCurrentLoadedPath = name;
@@ -497,8 +511,9 @@ std::unique_ptr<Intent> CreateSaveGameAsIntent()
 {
     auto name = Path::GetFileNameWithoutExtension(gScenarioSavePath);
 
-    auto intent = std::make_unique<Intent>(WindowClass::Loadsave);
-    intent->PutExtra(INTENT_EXTRA_LOADSAVE_TYPE, LOADSAVETYPE_SAVE | LOADSAVETYPE_GAME);
+    auto intent = std::make_unique<Intent>(WindowClass::loadsave);
+    intent->PutEnumExtra<LoadSaveAction>(INTENT_EXTRA_LOADSAVE_ACTION, LoadSaveAction::save);
+    intent->PutEnumExtra<LoadSaveType>(INTENT_EXTRA_LOADSAVE_TYPE, LoadSaveType::park);
     intent->PutExtra(INTENT_EXTRA_PATH, name);
 
     return intent;
@@ -506,21 +521,25 @@ std::unique_ptr<Intent> CreateSaveGameAsIntent()
 
 void SaveGameAs()
 {
+#ifdef __EMSCRIPTEN__
+    EmscriptenResetAutosave();
+#endif
     auto intent = CreateSaveGameAsIntent();
     ContextOpenIntent(intent.get());
 }
 
+#ifndef __EMSCRIPTEN__
 static void LimitAutosaveCount(const size_t numberOfFilesToKeep, bool processLandscapeFolder)
 {
     size_t autosavesCount = 0;
     size_t numAutosavesToDelete = 0;
 
-    auto environment = GetContext()->GetPlatformEnvironment();
-    auto folderDirectory = environment->GetDirectoryPath(DIRBASE::USER, DIRID::SAVE);
+    auto& environment = GetContext()->GetPlatformEnvironment();
+    auto folderDirectory = environment.GetDirectoryPath(DirBase::user, DirId::saves);
     char const* fileFilter = "autosave_*.park";
     if (processLandscapeFolder)
     {
-        folderDirectory = environment->GetDirectoryPath(DIRBASE::USER, DIRID::LANDSCAPE);
+        folderDirectory = environment.GetDirectoryPath(DirBase::user, DirId::landscapes);
         fileFilter = "autosave_*.park";
     }
 
@@ -571,12 +590,12 @@ static void LimitAutosaveCount(const size_t numberOfFilesToKeep, bool processLan
 
 void GameAutosave()
 {
-    auto subDirectory = DIRID::SAVE;
+    auto subDirectory = DirId::saves;
     const char* fileExtension = ".park";
     uint32_t saveFlags = 0x80000000;
-    if (gScreenFlags & SCREEN_FLAGS_EDITOR)
+    if (isInEditorMode())
     {
-        subDirectory = DIRID::LANDSCAPE;
+        subDirectory = DirId::landscapes;
         fileExtension = ".park";
         saveFlags |= 2;
     }
@@ -590,11 +609,11 @@ void GameAutosave()
         timeName, sizeof(timeName), "autosave_%04u-%02u-%02u_%02u-%02u-%02u%s", currentDate.year, currentDate.month,
         currentDate.day, currentTime.hour, currentTime.minute, currentTime.second, fileExtension);
 
-    int32_t autosavesToKeep = Config::Get().general.AutosaveAmount;
-    LimitAutosaveCount(autosavesToKeep - 1, (gScreenFlags & SCREEN_FLAGS_EDITOR));
+    int32_t autosavesToKeep = Config::Get().general.autosaveAmount;
+    LimitAutosaveCount(autosavesToKeep - 1, isInEditorMode());
 
-    auto env = GetContext()->GetPlatformEnvironment();
-    auto autosaveDir = Path::Combine(env->GetDirectoryPath(DIRBASE::USER, subDirectory), u8"autosave");
+    auto& env = GetContext()->GetPlatformEnvironment();
+    auto autosaveDir = Path::Combine(env.GetDirectoryPath(DirBase::user, subDirectory), u8"autosave");
     Path::CreateDirectory(autosaveDir);
 
     auto path = Path::Combine(autosaveDir, timeName);
@@ -606,21 +625,29 @@ void GameAutosave()
         File::Copy(path, backupPath, true);
     }
 
-    auto& gameState = GetGameState();
+    auto& gameState = getGameState();
 
     if (!ScenarioSave(gameState, path, saveFlags))
         Console::Error::WriteLine("Could not autosave the scenario. Is the save folder writeable?");
 }
-
-static void GameLoadOrQuitNoSavePromptCallback(int32_t result, const utf8* path)
+#else
+void GameAutosave()
 {
-    if (result == MODAL_RESULT_OK)
+    const auto savePath = Path::WithExtension("save", ".park");
+    SaveGameWithName(savePath);
+    EmscriptenSaveGame(false, true, LoadSaveType::park);
+}
+#endif // __EMSCRIPTEN__
+
+static void GameLoadOrQuitNoSavePromptCallback(ModalResult result, const utf8* path)
+{
+    if (result == ModalResult::ok)
     {
         GameNotifyMapChange();
         GameUnloadScripts();
 
         auto* windowMgr = Ui::GetWindowManager();
-        windowMgr->CloseByClass(WindowClass::EditorObjectSelection);
+        windowMgr->CloseByClass(WindowClass::editorObjectSelection);
 
         GameLoadScripts();
         GameNotifyMapChanged();
@@ -634,13 +661,16 @@ static void NewGameWindowCallback(const utf8* path)
     // Closing this will cause a Ride window to pop up, so we have to do this to ensure that
     // no windows are open (besides the toolbars and LoadSave window).
     auto* windowMgr = Ui::GetWindowManager();
-    windowMgr->CloseByClass(WindowClass::RideConstruction);
-    windowMgr->CloseAllExceptClass(WindowClass::Loadsave);
+    windowMgr->CloseByClass(WindowClass::rideConstruction);
+    windowMgr->CloseAllExceptClass(WindowClass::loadsave);
 
     GameNotifyMapChange();
     GetContext()->LoadParkFromFile(path, false, true);
     GameLoadScripts();
     GameNotifyMapChanged();
+#ifdef __EMSCRIPTEN__
+    EmscriptenResetAutosave();
+#endif
 }
 
 /**
@@ -649,58 +679,64 @@ static void NewGameWindowCallback(const utf8* path)
  */
 void GameLoadOrQuitNoSavePrompt()
 {
+    auto& gameState = getGameState();
+
     switch (gSavePromptMode)
     {
-        case PromptMode::SaveBeforeLoad:
+        case PromptMode::saveBeforeLoad:
         {
-            auto loadOrQuitAction = LoadOrQuitAction(LoadOrQuitModes::CloseSavePrompt);
-            GameActions::Execute(&loadOrQuitAction);
+            auto loadOrQuitAction = GameActions::LoadOrQuitAction(GameActions::LoadOrQuitModes::CloseSavePrompt);
+            GameActions::Execute(&loadOrQuitAction, gameState);
             ToolCancel();
-            if (gScreenFlags & SCREEN_FLAGS_SCENARIO_EDITOR)
+            if (gLegacyScene == LegacyScene::scenarioEditor)
             {
                 LoadLandscape();
             }
             else
             {
-                auto intent = Intent(WindowClass::Loadsave);
-                intent.PutExtra(INTENT_EXTRA_LOADSAVE_TYPE, LOADSAVETYPE_LOAD | LOADSAVETYPE_GAME);
+                auto intent = Intent(WindowClass::loadsave);
+                intent.PutEnumExtra<LoadSaveAction>(INTENT_EXTRA_LOADSAVE_ACTION, LoadSaveAction::load);
+                intent.PutEnumExtra<LoadSaveType>(INTENT_EXTRA_LOADSAVE_TYPE, LoadSaveType::park);
                 intent.PutExtra(INTENT_EXTRA_CALLBACK, reinterpret_cast<CloseCallback>(GameLoadOrQuitNoSavePromptCallback));
                 ContextOpenIntent(&intent);
             }
             break;
         }
-        case PromptMode::SaveBeforeQuit:
+        case PromptMode::saveBeforeQuit:
         {
-            auto loadOrQuitAction = LoadOrQuitAction(LoadOrQuitModes::CloseSavePrompt);
-            GameActions::Execute(&loadOrQuitAction);
+            auto loadOrQuitAction = GameActions::LoadOrQuitAction(GameActions::LoadOrQuitModes::CloseSavePrompt);
+            GameActions::Execute(&loadOrQuitAction, gameState);
             ToolCancel();
-            if (InputTestFlag(INPUT_FLAG_5))
+            if (gInputFlags.has(InputFlag::rightMousePressed))
             {
-                InputSetFlag(INPUT_FLAG_5, false);
+                gInputFlags.unset(InputFlag::rightMousePressed);
             }
             GameResetSpeed();
             gFirstTimeSaving = true;
             GameNotifyMapChange();
             GameUnloadScripts();
+#ifdef __EMSCRIPTEN__
+            EmscriptenResetAutosave();
+#endif
 
             auto* context = OpenRCT2::GetContext();
             context->SetActiveScene(context->GetTitleScene());
             break;
         }
-        case PromptMode::SaveBeforeNewGame:
+        case PromptMode::saveBeforeNewGame:
         {
-            auto loadOrQuitAction = LoadOrQuitAction(LoadOrQuitModes::CloseSavePrompt);
-            GameActions::Execute(&loadOrQuitAction);
+            auto loadOrQuitAction = GameActions::LoadOrQuitAction(GameActions::LoadOrQuitModes::CloseSavePrompt);
+            GameActions::Execute(&loadOrQuitAction, gameState);
             ToolCancel();
-            auto intent = Intent(WindowClass::ScenarioSelect);
+            auto intent = Intent(WindowClass::scenarioSelect);
             intent.PutExtra(INTENT_EXTRA_CALLBACK, reinterpret_cast<CloseCallback>(NewGameWindowCallback));
             ContextOpenIntent(&intent);
             break;
         }
         default:
             GameUnloadScripts();
-            ResetAllEntities();
-            OpenRCT2Finish();
+            getGameState().entities.ResetAllEntities();
+            GetContext()->Finish();
             break;
     }
 }
@@ -708,7 +744,7 @@ void GameLoadOrQuitNoSavePrompt()
 void StartSilentRecord()
 {
     std::string name = Path::Combine(
-        OpenRCT2::GetContext()->GetPlatformEnvironment()->GetDirectoryPath(OpenRCT2::DIRBASE::USER), u8"debug_replay.parkrep");
+        OpenRCT2::GetContext()->GetPlatformEnvironment().GetDirectoryPath(OpenRCT2::DirBase::user), u8"debug_replay.parkrep");
     auto* replayManager = OpenRCT2::GetContext()->GetReplayManager();
     if (replayManager->StartRecording(name, OpenRCT2::k_MaxReplayTicks, OpenRCT2::IReplayManager::RecordType::SILENT))
     {
@@ -754,9 +790,9 @@ void PrepareMapForSave()
 #ifdef ENABLE_SCRIPTING
     auto& scriptEngine = GetContext()->GetScriptEngine();
     auto& hookEngine = scriptEngine.GetHookEngine();
-    if (hookEngine.HasSubscriptions(OpenRCT2::Scripting::HOOK_TYPE::MAP_SAVE))
+    if (hookEngine.HasSubscriptions(OpenRCT2::Scripting::HookType::mapSave))
     {
-        hookEngine.Call(OpenRCT2::Scripting::HOOK_TYPE::MAP_SAVE, false);
+        hookEngine.Call(OpenRCT2::Scripting::HookType::mapSave, false);
     }
 #endif
 }
