@@ -14,7 +14,6 @@
 #include "../../../ride/TrackData.h"
 #include "../../../ride/TrackPaint.h"
 #include "../../../ride/Vehicle.h"
-#include "../../../world/Map.h"
 #include "../../../world/tile_element/TrackElement.h"
 #include "../../Paint.h"
 #include "../../support/WoodenSupports.h"
@@ -69,7 +68,7 @@ static void ReverserRCTrackFlat(
                 break;
         }
     }
-    DrawSupportForSequenceA<TrackElemType::Flat>(
+    DrawSupportForSequenceA<TrackElemType::flat>(
         session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
     PaintUtilPushTunnelRotated(session, direction, height, kTunnelGroup, TunnelSubType::Flat);
     PaintUtilSetSegmentSupportHeight(session, kSegmentsAll, 0xFFFF, 0);
@@ -89,7 +88,7 @@ static void ReverserRCTrackStation(
     PaintAddImageAsParentRotated(
         session, direction, session.TrackColours.WithIndex(imageIds[direction]), { 0, 0, height },
         { { 0, 2, height + 1 }, { 32, 27, 2 } });
-    DrawSupportForSequenceA<TrackElemType::EndStation>(
+    DrawSupportForSequenceA<TrackElemType::endStation>(
         session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
     TrackPaintUtilDrawStation2(session, ride, direction, height, trackElement, StationBaseType::a, 0, 9, 11);
     TrackPaintUtilDrawStationTunnel(session, direction, height);
@@ -154,7 +153,7 @@ static void ReverserRCTrack25DegUp(
                 break;
         }
     }
-    DrawSupportForSequenceA<TrackElemType::Up25>(
+    DrawSupportForSequenceA<TrackElemType::up25>(
         session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
     if (direction == 0 || direction == 3)
     {
@@ -225,7 +224,7 @@ static void ReverserRCTrackFlatTo25DegUp(
                 break;
         }
     }
-    DrawSupportForSequenceA<TrackElemType::FlatToUp25>(
+    DrawSupportForSequenceA<TrackElemType::flatToUp25>(
         session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
     if (direction == 0 || direction == 3)
     {
@@ -296,7 +295,7 @@ static void ReverserRCTrack25DegUpToFlat(
                 break;
         }
     }
-    DrawSupportForSequenceA<TrackElemType::Up25ToFlat>(
+    DrawSupportForSequenceA<TrackElemType::up25ToFlat>(
         session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
     if (direction == 0 || direction == 3)
     {
@@ -361,7 +360,7 @@ static void ReverserRCTrackLeftQuarterTurn5(
                         session, direction, session.TrackColours.WithIndex(21538), { 0, 2, height }, { 32, 32, 2 });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::LeftQuarterTurn5Tiles>(
+            DrawSupportForSequenceA<TrackElemType::leftQuarterTurn5Tiles>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             if (direction == 0 || direction == 3)
             {
@@ -398,7 +397,7 @@ static void ReverserRCTrackLeftQuarterTurn5(
                         session, direction, session.TrackColours.WithIndex(21537), { 0, 16, height }, { 32, 16, 2 });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::LeftQuarterTurn5Tiles>(
+            DrawSupportForSequenceA<TrackElemType::leftQuarterTurn5Tiles>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             PaintUtilSetSegmentSupportHeight(
                 session,
@@ -430,7 +429,7 @@ static void ReverserRCTrackLeftQuarterTurn5(
                         session, direction, session.TrackColours.WithIndex(21536), { 0, 0, height }, { 16, 16, 2 });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::LeftQuarterTurn5Tiles>(
+            DrawSupportForSequenceA<TrackElemType::leftQuarterTurn5Tiles>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             PaintUtilSetSegmentSupportHeight(
                 session,
@@ -470,7 +469,7 @@ static void ReverserRCTrackLeftQuarterTurn5(
                         session, direction, session.TrackColours.WithIndex(21535), { 16, 0, height }, { 16, 32, 2 });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::LeftQuarterTurn5Tiles>(
+            DrawSupportForSequenceA<TrackElemType::leftQuarterTurn5Tiles>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             PaintUtilSetSegmentSupportHeight(
                 session,
@@ -502,7 +501,7 @@ static void ReverserRCTrackLeftQuarterTurn5(
                         session, direction, session.TrackColours.WithIndex(21534), { 2, 0, height }, { 32, 32, 2 });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::LeftQuarterTurn5Tiles>(
+            DrawSupportForSequenceA<TrackElemType::leftQuarterTurn5Tiles>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             switch (direction)
             {
@@ -559,7 +558,7 @@ static void ReverserRCTrackSBendLeft(
                         { { 0, 2, height }, { 32, 27, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::SBendLeft>(
+            DrawSupportForSequenceA<TrackElemType::sBendLeft>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             if (direction == 0 || direction == 3)
             {
@@ -592,7 +591,7 @@ static void ReverserRCTrackSBendLeft(
                         { { 0, 6, height }, { 32, 26, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::SBendLeft>(
+            DrawSupportForSequenceA<TrackElemType::sBendLeft>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             PaintUtilSetSegmentSupportHeight(
                 session,
@@ -628,7 +627,7 @@ static void ReverserRCTrackSBendLeft(
                         { { 0, 0, height }, { 32, 26, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::SBendLeft>(
+            DrawSupportForSequenceA<TrackElemType::sBendLeft>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             PaintUtilSetSegmentSupportHeight(
                 session,
@@ -664,7 +663,7 @@ static void ReverserRCTrackSBendLeft(
                         { { 0, 2, height }, { 32, 27, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::SBendLeft>(
+            DrawSupportForSequenceA<TrackElemType::sBendLeft>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             switch (direction)
             {
@@ -712,7 +711,7 @@ static void ReverserRCTrackSBendRight(
                         { { 0, 2, height }, { 32, 27, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::SBendRight>(
+            DrawSupportForSequenceA<TrackElemType::sBendRight>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             if (direction == 0 || direction == 3)
             {
@@ -745,7 +744,7 @@ static void ReverserRCTrackSBendRight(
                         { { 0, 0, height }, { 32, 26, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::SBendRight>(
+            DrawSupportForSequenceA<TrackElemType::sBendRight>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             PaintUtilSetSegmentSupportHeight(
                 session,
@@ -781,7 +780,7 @@ static void ReverserRCTrackSBendRight(
                         { { 0, 6, height }, { 32, 26, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::SBendRight>(
+            DrawSupportForSequenceA<TrackElemType::sBendRight>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             PaintUtilSetSegmentSupportHeight(
                 session,
@@ -817,7 +816,7 @@ static void ReverserRCTrackSBendRight(
                         { { 0, 2, height }, { 32, 27, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::SBendRight>(
+            DrawSupportForSequenceA<TrackElemType::sBendRight>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             switch (direction)
             {
@@ -865,7 +864,7 @@ static void ReverserRCTrackLeftQuarterTurn3(
                         { { 0, 6, height }, { 32, 20, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::LeftQuarterTurn3Tiles>(
+            DrawSupportForSequenceA<TrackElemType::leftQuarterTurn3Tiles>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             if (direction == 0 || direction == 3)
             {
@@ -933,7 +932,7 @@ static void ReverserRCTrackLeftQuarterTurn3(
                         { { 6, 0, height }, { 20, 32, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::LeftQuarterTurn3Tiles>(
+            DrawSupportForSequenceA<TrackElemType::leftQuarterTurn3Tiles>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             switch (direction)
             {
@@ -979,7 +978,7 @@ static void ReverserRCTrackBrakes(
                 { { 0, 2, height }, { 32, 27, 2 } });
             break;
     }
-    DrawSupportForSequenceA<TrackElemType::Brakes>(
+    DrawSupportForSequenceA<TrackElemType::brakes>(
         session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
     PaintUtilPushTunnelRotated(session, direction, height, kTunnelGroup, TunnelSubType::Flat);
     PaintUtilSetSegmentSupportHeight(session, kSegmentsAll, 0xFFFF, 0);
@@ -1017,7 +1016,7 @@ static void ReverserRCTrackLeftReverser(
                         { { 0, 2, height }, { 32, 27, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::LeftReverser>(
+            DrawSupportForSequenceA<TrackElemType::leftReverser>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             if (direction == 0 || direction == 3)
             {
@@ -1048,7 +1047,7 @@ static void ReverserRCTrackLeftReverser(
                         { { 0, 2, height }, { 32, 27, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::LeftReverser>(
+            DrawSupportForSequenceA<TrackElemType::leftReverser>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             break;
         case 2:
@@ -1075,7 +1074,7 @@ static void ReverserRCTrackLeftReverser(
                         { { 0, 2, height }, { 32, 27, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::LeftReverser>(
+            DrawSupportForSequenceA<TrackElemType::leftReverser>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             break;
         case 3:
@@ -1102,7 +1101,7 @@ static void ReverserRCTrackLeftReverser(
                         { { 0, 2, height }, { 32, 27, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::LeftReverser>(
+            DrawSupportForSequenceA<TrackElemType::leftReverser>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             break;
         case 4:
@@ -1129,7 +1128,7 @@ static void ReverserRCTrackLeftReverser(
                         { { 0, 2, height }, { 32, 27, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::LeftReverser>(
+            DrawSupportForSequenceA<TrackElemType::leftReverser>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             break;
         case 5:
@@ -1156,7 +1155,7 @@ static void ReverserRCTrackLeftReverser(
                         { { 0, 2, height }, { 32, 27, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::LeftReverser>(
+            DrawSupportForSequenceA<TrackElemType::leftReverser>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             switch (direction)
             {
@@ -1205,7 +1204,7 @@ static void ReverserRCTrackRightReverser(
                         { { 0, 2, height }, { 32, 27, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::RightReverser>(
+            DrawSupportForSequenceA<TrackElemType::rightReverser>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             if (direction == 0 || direction == 3)
             {
@@ -1238,7 +1237,7 @@ static void ReverserRCTrackRightReverser(
                         { { 0, 2, height }, { 32, 27, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::RightReverser>(
+            DrawSupportForSequenceA<TrackElemType::rightReverser>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             PaintUtilSetSegmentSupportHeight(session, kSegmentsAll, 0xFFFF, 0);
             PaintUtilSetGeneralSupportHeight(session, height + kDefaultGeneralSupportHeight);
@@ -1267,7 +1266,7 @@ static void ReverserRCTrackRightReverser(
                         { { 0, 2, height }, { 32, 27, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::RightReverser>(
+            DrawSupportForSequenceA<TrackElemType::rightReverser>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             PaintUtilSetSegmentSupportHeight(session, kSegmentsAll, 0xFFFF, 0);
             PaintUtilSetGeneralSupportHeight(session, height + kDefaultGeneralSupportHeight);
@@ -1296,7 +1295,7 @@ static void ReverserRCTrackRightReverser(
                         { { 0, 2, height }, { 32, 27, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::RightReverser>(
+            DrawSupportForSequenceA<TrackElemType::rightReverser>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             PaintUtilSetSegmentSupportHeight(session, kSegmentsAll, 0xFFFF, 0);
             PaintUtilSetGeneralSupportHeight(session, height + kDefaultGeneralSupportHeight);
@@ -1325,7 +1324,7 @@ static void ReverserRCTrackRightReverser(
                         { { 0, 2, height }, { 32, 27, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::RightReverser>(
+            DrawSupportForSequenceA<TrackElemType::rightReverser>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             PaintUtilSetSegmentSupportHeight(session, kSegmentsAll, 0xFFFF, 0);
             PaintUtilSetGeneralSupportHeight(session, height + kDefaultGeneralSupportHeight);
@@ -1354,7 +1353,7 @@ static void ReverserRCTrackRightReverser(
                         { { 0, 2, height }, { 32, 27, 2 } });
                     break;
             }
-            DrawSupportForSequenceA<TrackElemType::RightReverser>(
+            DrawSupportForSequenceA<TrackElemType::rightReverser>(
                 session, supportType.wooden, trackSequence, direction, height, session.SupportColours);
             switch (direction)
             {
@@ -1375,41 +1374,41 @@ TrackPaintFunction GetTrackPaintFunctionReverserRC(OpenRCT2::TrackElemType track
 {
     switch (trackType)
     {
-        case TrackElemType::Flat:
+        case TrackElemType::flat:
             return ReverserRCTrackFlat;
-        case TrackElemType::EndStation:
-        case TrackElemType::BeginStation:
-        case TrackElemType::MiddleStation:
+        case TrackElemType::endStation:
+        case TrackElemType::beginStation:
+        case TrackElemType::middleStation:
             return ReverserRCTrackStation;
-        case TrackElemType::Up25:
+        case TrackElemType::up25:
             return ReverserRCTrack25DegUp;
-        case TrackElemType::FlatToUp25:
+        case TrackElemType::flatToUp25:
             return ReverserRCTrackFlatTo25DegUp;
-        case TrackElemType::Up25ToFlat:
+        case TrackElemType::up25ToFlat:
             return ReverserRCTrack25DegUpToFlat;
-        case TrackElemType::Down25:
+        case TrackElemType::down25:
             return ReverserRCTrack25DegDown;
-        case TrackElemType::FlatToDown25:
+        case TrackElemType::flatToDown25:
             return ReverserRCTrackFlatTo25DegDown;
-        case TrackElemType::Down25ToFlat:
+        case TrackElemType::down25ToFlat:
             return ReverserRCTrack25DegDownToFlat;
-        case TrackElemType::LeftQuarterTurn5Tiles:
+        case TrackElemType::leftQuarterTurn5Tiles:
             return ReverserRCTrackLeftQuarterTurn5;
-        case TrackElemType::RightQuarterTurn5Tiles:
+        case TrackElemType::rightQuarterTurn5Tiles:
             return ReverserRCTrackRightQuarterTurn5;
-        case TrackElemType::SBendLeft:
+        case TrackElemType::sBendLeft:
             return ReverserRCTrackSBendLeft;
-        case TrackElemType::SBendRight:
+        case TrackElemType::sBendRight:
             return ReverserRCTrackSBendRight;
-        case TrackElemType::LeftQuarterTurn3Tiles:
+        case TrackElemType::leftQuarterTurn3Tiles:
             return ReverserRCTrackLeftQuarterTurn3;
-        case TrackElemType::RightQuarterTurn3Tiles:
+        case TrackElemType::rightQuarterTurn3Tiles:
             return ReverserRCTrackRightQuarterTurn3;
-        case TrackElemType::Brakes:
+        case TrackElemType::brakes:
             return ReverserRCTrackBrakes;
-        case TrackElemType::LeftReverser:
+        case TrackElemType::leftReverser:
             return ReverserRCTrackLeftReverser;
-        case TrackElemType::RightReverser:
+        case TrackElemType::rightReverser:
             return ReverserRCTrackRightReverser;
         default:
             return TrackPaintFunctionDummy;
