@@ -20,7 +20,7 @@ namespace OpenRCT2
 constexpr RideTypeDescriptor CompactInvertedCoasterRTD =
 {
     .Category = RideCategory::rollerCoaster,
-    .StartTrackPiece = TrackElemType::EndStation,
+    .StartTrackPiece = TrackElemType::endStation,
     .TrackPaintFunctions = TrackDrawerDescriptor({
         .trackStyle = TrackStyle::compactInvertedCoaster,
         .supportType = MetalSupportType::tubesInverted,
@@ -30,7 +30,7 @@ constexpr RideTypeDescriptor CompactInvertedCoasterRTD =
     .InvertedTrackPaintFunctions = {},
     .Flags = kRtdFlagsHasThreeColours | kRtdFlagsCommonCoaster | kRtdFlagsCommonCoasterNonAlt | 
         EnumsToFlags(RtdFlag::hasLeaveWhenAnotherVehicleArrivesAtStation, RtdFlag::checkGForces, 
-                     RtdFlag::allowMultipleCircuits, RtdFlag::isSuspended),
+                     RtdFlag::allowMultipleCircuits, RtdFlag::isSuspended, RtdFlag::reverseInclineLaunchAffectsReliability),
     .RideModes = EnumsToFlags(RideMode::continuousCircuit, RideMode::continuousCircuitBlockSectioned, RideMode::reverseInclineLaunchedShuttle),
     .DefaultMode = RideMode::continuousCircuit,
     .OperatingSettings = { 7, 27 },
@@ -45,7 +45,7 @@ constexpr RideTypeDescriptor CompactInvertedCoasterRTD =
     .BuildCosts = { 50.00_GBP, 2.50_GBP, 50, },
     .DefaultPrices = { 20, 20 },
     .DefaultMusic = kMusicObjectTechno,
-    .PhotoItem = ShopItem::Photo2,
+    .PhotoItem = ShopItem::photo2,
     .BonusValue = 80,
     .ColourPresets = TRACK_COLOUR_PRESETS(
         { COLOUR_BRIGHT_YELLOW, COLOUR_BRIGHT_YELLOW, COLOUR_BRIGHT_RED },
